| Title: | 'shiny' Applications for the 'tesselle' Packages |
|---|---|
| Description: | A collection of 'shiny' applications for the 'tesselle' packages <https://www.tesselle.org/>. This package provides applications for archaeological data analysis and visualization. These mainly, but not exclusively, include applications for chronological modelling (e.g. matrix seriation, aoristic analysis) and count data analysis (e.g. diversity measures, compositional data analysis). |
| Authors: | Nicolas Frerebeau [aut, cre] (ORCID: <https://orcid.org/0000-0001-5759-4944>), Brice Lebrun [art] (ORCID: <https://orcid.org/0000-0001-7503-8685>, Logo designer), Université Bordeaux Montaigne [fnd] (ROR: <https://ror.org/03pbgwk21>), CNRS [fnd] (ROR: <https://ror.org/02feahw73>) |
| Maintainer: | Nicolas Frerebeau <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.3.1.9000 |
| Built: | 2026-06-03 06:58:00 UTC |
| Source: | https://codeberg.org/tesselle/kinesis |
A wrapper for shiny::shinyAppDir().
run_app( app = c("diversity", "seriation", "aoristic", "mcd", "source", "scatter", "ternary", "ca", "pca"), options = list(launch.browser = interactive()) )run_app( app = c("diversity", "seriation", "aoristic", "mcd", "source", "scatter", "ternary", "ca", "pca"), options = list(launch.browser = interactive()) )
app |
A |
options |
A |
| Application name | Keyword |
| Aoristic Analysis | aoristic |
| Correspondence Analysis | ca |
| Principal Components Analysis | pca |
| Diversity Measures | diversity |
| Mean Ceramic Date | mcd |
| Scatter Plot | scatter |
| Matrix Seriation | seriation |
| Compositional Data Analysis | source |
| Ternary Plot | ternary
|
A shiny application object.
N. Frerebeau
if (interactive()) { run_app("seriation") }if (interactive()) { run_app("seriation") }